
# Slot: default_prefix


default and base prefix -- used for ':' identifiers, @base and @vocab

URI: [linkml:default_prefix](https://w3id.org/linkml/default_prefix)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
